Crate mollusk_svm_fuzz_fixture

Crate mollusk_svm_fuzz_fixture 

Mollusk SVM Fuzz: Mollusk-compatible fuzz fixture for SVM programs.

Note: The fixtures defined in this library are compatible with Mollusk, which means developers can fuzz programs using the Mollusk harness. However, these fixtures (and this library) do not depend on the harness. They can be used to fuzz a custom entrypoint of the developer’s choice.

Modules

account
An account with an address: (Pubkey, Account).
compute_budget
Compute budget for instructions.
context
All test environment inputs for an instruction.
effects
Post-invocation effects of an instruction.
feature_set
Runtime feature set.
proto
sysvars
Runtime sysvars.

Structs

Fixture
A fixture for invoking a single instruction against a simulated SVM program runtime environment, for a given program.